__wt_event_handler

Struct __wt_event_handler 

#[repr(C)]
pub struct __wt_event_handler { pub handle_error: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, error: c_int, message: *const c_char) -> c_int>, pub handle_message: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, message: *const c_char) -> c_int>, pub handle_progress: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, operation: *const c_char, progress: u64) -> c_int>, pub handle_close: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, cursor: *mut WT_CURSOR) -> c_int>, }
The interface implemented by applications to handle error, informational and progress messages. Entries set to NULL are ignored and the default handlers will continue to be used.

Fields

handle_error: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, error: c_int, message: *const c_char) -> c_int>

Callback to handle error messages; by default, error messages are written to the stderr stream. See @ref event_message_handling for more information.

Errors that require the application to exit and restart will have their \c error value set to \c WT_PANIC. The application can exit immediately when \c WT_PANIC is passed to an event handler, there is no reason to return into WiredTiger.

Event handler returns are not ignored: if the handler returns non-zero, the error may cause the WiredTiger function posting the event to fail, and may even cause operation or library failure.

@param session the WiredTiger session handle in use when the error was generated. The handle may have been created by the application or automatically by WiredTiger. @param error a return value from a WiredTiger, ISO C, or POSIX standard API, which can be converted to a string using WT_SESSION::strerror @param message an error string

handle_message: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, message: *const c_char) -> c_int>

Callback to handle informational messages; by default, informational messages are written to the stdout stream. See @ref event_message_handling for more information.

Message handler returns are not ignored: if the handler returns non-zero, the error may cause the WiredTiger function posting the event to fail, and may even cause operation or library failure.

@param session the WiredTiger session handle in use when the message was generated. The handle may have been created by the application or automatically by WiredTiger. @param message an informational string

handle_progress: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, operation: *const c_char, progress: u64) -> c_int>

Callback to handle progress messages; by default, progress messages are not written. See @ref event_message_handling for more information.

Progress handler returns are not ignored: if the handler returns non-zero, the error may cause the WiredTiger function posting the event to fail, and may even cause operation or library failure.

@param session the WiredTiger session handle in use when the progress message was generated. The handle may have been created by the application or automatically by WiredTiger. @param operation a string representation of the operation @param progress a counter

handle_close: Option<unsafe extern "C" fn(handler: *mut WT_EVENT_HANDLER, session: *mut WT_SESSION, cursor: *mut WT_CURSOR) -> c_int>

Callback to handle automatic close of a WiredTiger handle.

Close handler returns are not ignored: if the handler returns non-zero, the error may cause the WiredTiger function posting the event to fail, and may even cause operation or library failure.

@param session The session handle that is being closed if the cursor parameter is NULL. @param cursor The cursor handle that is being closed, or NULL if it is a session handle being closed.